# coding: utf-8

# flake8: noqa
"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2020.08.24
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from agilicus_api.models.add_group_member_request import AddGroupMemberRequest
from agilicus_api.models.application import Application
from agilicus_api.models.application_assignment import ApplicationAssignment
from agilicus_api.models.application_service import ApplicationService
from agilicus_api.models.application_service_assignment import ApplicationServiceAssignment
from agilicus_api.models.application_summary import ApplicationSummary
from agilicus_api.models.application_summary_status import ApplicationSummaryStatus
from agilicus_api.models.audit import Audit
from agilicus_api.models.auth_audits import AuthAudits
from agilicus_api.models.catalogue import Catalogue
from agilicus_api.models.catalogue_entry import CatalogueEntry
from agilicus_api.models.challenge import Challenge
from agilicus_api.models.challenge_answer import ChallengeAnswer
from agilicus_api.models.challenge_answer_spec import ChallengeAnswerSpec
from agilicus_api.models.challenge_endpoint import ChallengeEndpoint
from agilicus_api.models.challenge_spec import ChallengeSpec
from agilicus_api.models.challenge_status import ChallengeStatus
from agilicus_api.models.combined_rules import CombinedRules
from agilicus_api.models.combined_rules_status import CombinedRulesStatus
from agilicus_api.models.combined_user_detail import CombinedUserDetail
from agilicus_api.models.combined_user_detail_status import CombinedUserDetailStatus
from agilicus_api.models.common_metadata import CommonMetadata
from agilicus_api.models.create_token_request import CreateTokenRequest
from agilicus_api.models.definition import Definition
from agilicus_api.models.environment import Environment
from agilicus_api.models.environment_config import EnvironmentConfig
from agilicus_api.models.environment_config_var import EnvironmentConfigVar
from agilicus_api.models.environment_status import EnvironmentStatus
from agilicus_api.models.error_message import ErrorMessage
from agilicus_api.models.file import File
from agilicus_api.models.file_summary import FileSummary
from agilicus_api.models.file_upload import FileUpload
from agilicus_api.models.group import Group
from agilicus_api.models.group_data import GroupData
from agilicus_api.models.group_member import GroupMember
from agilicus_api.models.host_permissions import HostPermissions
from agilicus_api.models.http_rule import HttpRule
from agilicus_api.models.included_role import IncludedRole
from agilicus_api.models.issuer import Issuer
from agilicus_api.models.issuer_client import IssuerClient
from agilicus_api.models.json_body_constraint import JSONBodyConstraint
from agilicus_api.models.list_active_users_response import ListActiveUsersResponse
from agilicus_api.models.list_application_services_response import ListApplicationServicesResponse
from agilicus_api.models.list_application_summary_response import ListApplicationSummaryResponse
from agilicus_api.models.list_applications_response import ListApplicationsResponse
from agilicus_api.models.list_audits_response import ListAuditsResponse
from agilicus_api.models.list_auth_audits_response import ListAuthAuditsResponse
from agilicus_api.models.list_catalogue_entries_response import ListCatalogueEntriesResponse
from agilicus_api.models.list_catalogues_response import ListCataloguesResponse
from agilicus_api.models.list_combined_rules_response import ListCombinedRulesResponse
from agilicus_api.models.list_combined_user_details_response import ListCombinedUserDetailsResponse
from agilicus_api.models.list_configs_response import ListConfigsResponse
from agilicus_api.models.list_elevated_user_roles import ListElevatedUserRoles
from agilicus_api.models.list_environment_configs_response import ListEnvironmentConfigsResponse
from agilicus_api.models.list_files_response import ListFilesResponse
from agilicus_api.models.list_groups_response import ListGroupsResponse
from agilicus_api.models.list_issuer_clients_response import ListIssuerClientsResponse
from agilicus_api.models.list_issuer_extensions_response import ListIssuerExtensionsResponse
from agilicus_api.models.list_issuer_roots_response import ListIssuerRootsResponse
from agilicus_api.models.list_logs_response import ListLogsResponse
from agilicus_api.models.list_mfa_challenge_methods import ListMFAChallengeMethods
from agilicus_api.models.list_message_endpoints_response import ListMessageEndpointsResponse
from agilicus_api.models.list_orgs_response import ListOrgsResponse
from agilicus_api.models.list_role_to_rule_entries import ListRoleToRuleEntries
from agilicus_api.models.list_roles import ListRoles
from agilicus_api.models.list_rules import ListRules
from agilicus_api.models.list_services_response import ListServicesResponse
from agilicus_api.models.list_totp_enrollment_response import ListTOTPEnrollmentResponse
from agilicus_api.models.list_tokens_response import ListTokensResponse
from agilicus_api.models.list_top_users_response import ListTopUsersResponse
from agilicus_api.models.list_upstream_user_identities_response import ListUpstreamUserIdentitiesResponse
from agilicus_api.models.list_user_application_access_info_response import ListUserApplicationAccessInfoResponse
from agilicus_api.models.list_user_guids_response import ListUserGuidsResponse
from agilicus_api.models.list_user_request_info_response import ListUserRequestInfoResponse
from agilicus_api.models.list_users_response import ListUsersResponse
from agilicus_api.models.list_web_auth_n_enrollment_response import ListWebAuthNEnrollmentResponse
from agilicus_api.models.log import Log
from agilicus_api.models.mfa_challenge_method import MFAChallengeMethod
from agilicus_api.models.mfa_challenge_method_spec import MFAChallengeMethodSpec
from agilicus_api.models.managed_upstream_identity_provider import ManagedUpstreamIdentityProvider
from agilicus_api.models.message import Message
from agilicus_api.models.message_action import MessageAction
from agilicus_api.models.message_endpoint import MessageEndpoint
from agilicus_api.models.message_endpoint_metadata import MessageEndpointMetadata
from agilicus_api.models.message_endpoint_spec import MessageEndpointSpec
from agilicus_api.models.message_endpoint_type import MessageEndpointType
from agilicus_api.models.message_endpoint_type_web_push import MessageEndpointTypeWebPush
from agilicus_api.models.message_endpoints_config import MessageEndpointsConfig
from agilicus_api.models.metadata_with_id import MetadataWithId
from agilicus_api.models.metadata_with_id_all_of import MetadataWithIdAllOf
from agilicus_api.models.metadata_with_only_id import MetadataWithOnlyId
from agilicus_api.models.oidc_upstream_identity_provider import OIDCUpstreamIdentityProvider
from agilicus_api.models.organisation import Organisation
from agilicus_api.models.organisation_admin import OrganisationAdmin
from agilicus_api.models.raw_token import RawToken
from agilicus_api.models.rendered_query_parameter import RenderedQueryParameter
from agilicus_api.models.rendered_rule import RenderedRule
from agilicus_api.models.rendered_rule_body import RenderedRuleBody
from agilicus_api.models.replace_user_role_request import ReplaceUserRoleRequest
from agilicus_api.models.reset_mfa_challenge_method import ResetMFAChallengeMethod
from agilicus_api.models.role import Role
from agilicus_api.models.role_list import RoleList
from agilicus_api.models.role_spec import RoleSpec
from agilicus_api.models.role_to_rule_entry import RoleToRuleEntry
from agilicus_api.models.role_to_rule_entry_spec import RoleToRuleEntrySpec
from agilicus_api.models.role_v2 import RoleV2
from agilicus_api.models.roles import Roles
from agilicus_api.models.rule import Rule
from agilicus_api.models.rule_query_body import RuleQueryBody
from agilicus_api.models.rule_query_body_json import RuleQueryBodyJSON
from agilicus_api.models.rule_query_parameter import RuleQueryParameter
from agilicus_api.models.rule_scope_enum import RuleScopeEnum
from agilicus_api.models.rule_spec import RuleSpec
from agilicus_api.models.rule_v2 import RuleV2
from agilicus_api.models.runtime_status import RuntimeStatus
from agilicus_api.models.service import Service
from agilicus_api.models.storage_region import StorageRegion
from agilicus_api.models.totp_enrollment import TOTPEnrollment
from agilicus_api.models.totp_enrollment_answer import TOTPEnrollmentAnswer
from agilicus_api.models.totp_enrollment_spec import TOTPEnrollmentSpec
from agilicus_api.models.totp_enrollment_status import TOTPEnrollmentStatus
from agilicus_api.models.time_interval_metrics import TimeIntervalMetrics
from agilicus_api.models.time_validity import TimeValidity
from agilicus_api.models.token import Token
from agilicus_api.models.token_introspect import TokenIntrospect
from agilicus_api.models.token_introspect_options import TokenIntrospectOptions
from agilicus_api.models.token_reissue_request import TokenReissueRequest
from agilicus_api.models.token_revoke import TokenRevoke
from agilicus_api.models.token_validity import TokenValidity
from agilicus_api.models.upstream_user_identity import UpstreamUserIdentity
from agilicus_api.models.upstream_user_identity_spec import UpstreamUserIdentitySpec
from agilicus_api.models.user import User
from agilicus_api.models.user_application_access_info import UserApplicationAccessInfo
from agilicus_api.models.user_application_access_info_status import UserApplicationAccessInfoStatus
from agilicus_api.models.user_identity import UserIdentity
from agilicus_api.models.user_identity_update import UserIdentityUpdate
from agilicus_api.models.user_identity_update_spec import UserIdentityUpdateSpec
from agilicus_api.models.user_info import UserInfo
from agilicus_api.models.user_member_of import UserMemberOf
from agilicus_api.models.user_metrics import UserMetrics
from agilicus_api.models.user_request_info import UserRequestInfo
from agilicus_api.models.user_request_info_spec import UserRequestInfoSpec
from agilicus_api.models.user_request_info_status import UserRequestInfoStatus
from agilicus_api.models.user_roles import UserRoles
from agilicus_api.models.user_summary import UserSummary
from agilicus_api.models.web_auth_n_enrollment import WebAuthNEnrollment
from agilicus_api.models.web_auth_n_enrollment_answer import WebAuthNEnrollmentAnswer
from agilicus_api.models.web_auth_n_enrollment_spec import WebAuthNEnrollmentSpec
from agilicus_api.models.web_auth_n_enrollment_status import WebAuthNEnrollmentStatus
from agilicus_api.models.whoami_request import WhoamiRequest
from agilicus_api.models.whoami_response import WhoamiResponse



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2020.08.24
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class MessageEndpointSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'endpoint_type': 'MessageEndpointType',
        'nickname': 'str',
        'address': 'str',
        'enabled': 'bool'
    }

    attribute_map = {
        'endpoint_type': 'endpoint_type',
        'nickname': 'nickname',
        'address': 'address',
        'enabled': 'enabled'
    }

    def __init__(self, endpoint_type=None, nickname=None, address=None, enabled=None, local_vars_configuration=None):  # noqa: E501
        """MessageEndpointSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._endpoint_type = None
        self._nickname = None
        self._address = None
        self._enabled = None
        self.discriminator = None

        if endpoint_type is not None:
            self.endpoint_type = endpoint_type
        if nickname is not None:
            self.nickname = nickname
        if address is not None:
            self.address = address
        if enabled is not None:
            self.enabled = enabled

    @property
    def endpoint_type(self):
        """Gets the endpoint_type of this MessageEndpointSpec.  # noqa: E501


        :return: The endpoint_type of this MessageEndpointSpec.  # noqa: E501
        :rtype: MessageEndpointType
        """
        return self._endpoint_type

    @endpoint_type.setter
    def endpoint_type(self, endpoint_type):
        """Sets the endpoint_type of this MessageEndpointSpec.


        :param endpoint_type: The endpoint_type of this MessageEndpointSpec.  # noqa: E501
        :type: MessageEndpointType
        """

        self._endpoint_type = endpoint_type

    @property
    def nickname(self):
        """Gets the nickname of this MessageEndpointSpec.  # noqa: E501

        User-supplied name (e.g. My-Yubikey, don's laptop)  # noqa: E501

        :return: The nickname of this MessageEndpointSpec.  # noqa: E501
        :rtype: str
        """
        return self._nickname

    @nickname.setter
    def nickname(self, nickname):
        """Sets the nickname of this MessageEndpointSpec.

        User-supplied name (e.g. My-Yubikey, don's laptop)  # noqa: E501

        :param nickname: The nickname of this MessageEndpointSpec.  # noqa: E501
        :type: str
        """

        self._nickname = nickname

    @property
    def address(self):
        """Gets the address of this MessageEndpointSpec.  # noqa: E501

        Type-specific address info (e.g. phone num, push-context json, ...)  # noqa: E501

        :return: The address of this MessageEndpointSpec.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this MessageEndpointSpec.

        Type-specific address info (e.g. phone num, push-context json, ...)  # noqa: E501

        :param address: The address of this MessageEndpointSpec.  # noqa: E501
        :type: str
        """

        self._address = address

    @property
    def enabled(self):
        """Gets the enabled of this MessageEndpointSpec.  # noqa: E501

        The status of the message endpoint, `true` when the endpoint is enabled, and `false` when the endpoint is disabled.  # noqa: E501

        :return: The enabled of this MessageEndpointSpec.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this MessageEndpointSpec.

        The status of the message endpoint, `true` when the endpoint is enabled, and `false` when the endpoint is disabled.  # noqa: E501

        :param enabled: The enabled of this MessageEndpointSpec.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MessageEndpointSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MessageEndpointSpec):
            return True

        return self.to_dict() != other.to_dict()
